""" Just a test file """
import unittest
from example_pkg.switch import switch, _say_hello, _say_goodbye, _unknown_salute

class TestSwitch(unittest.TestCase):
    def test_say_hello(self):
        self.assertEqual(_say_hello(), switch(0))

    def test_say_goodbye(self):
        self.assertEqual(_say_goodbye(), switch(1))

    def test_unknown_salute(self):
        self.assertEqual(_unknown_salute(), switch(2))

if __name__ == '__main__':
    unittest.main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pip-example-pkg-revuel",
    version="0.10.1",
    author="revuel",
    author_email="revuel22@hotmail.com",
    description="Tutorial to distribute a pip package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/revuel/pip-example-pkg-revule",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: Other/Proprietary License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)



""" Switch example for python 3 """


def _say_hello() -> str:
    return 'Hello'


def _say_goodbye() -> str:
    return 'Good bye'


def _unknown_salute() -> str:
    return 'Unknown salute :('


# Cases are outside the "switch" method in order to create them just once
_CASES = {0: _say_hello, 1: _say_goodbye}


def switch(case: int) -> str:
    """
    Switch like method
    :param case: Case
    :return: Case evaluation
    """
    return _CASES.get(case, _unknown_salute)()


if __name__ == '__main__':
    print(f'{switch(0)}, {switch(1)}, {switch(2)}')
